'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _exec = require('./exec');

var _exec2 = _interopRequireDefault(_exec);

var _logger = require('./logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Internal dependencies
 */
function tagExists(tagName) {
	var args = ['rev-parse', tagName];

	var exists = false;
	try {
		_exec2.default.git.apply(_exec2.default, args);
		exists = true;
	} catch (e) {}

	return exists;
}

function tag(tagName) {
	var args = ['tag', tagName];

	if (tagExists(tagName)) {
		_logger2.default.warning('tag ' + tagName + ' already exists.');
	} else {
		_exec2.default.git.apply(_exec2.default, args);
	}
}

function getCurrentBranch() {
	var args = ['symbolic-ref', '--short', '-q', 'HEAD'];

	var branch = void 0;
	try {
		branch = _exec2.default.git.apply(_exec2.default, args);
		branch = branch.trim();
	} catch (e) {
		throw new Error('Not on any branch. Maybe in "detached HEAD" state.');
	}

	return branch;
}

function checkout(branch) {
	var args = ['checkout', branch];
	_exec2.default.git.apply(_exec2.default, args);
}

function checkUncommittedChanges() {
	var args = ['diff-index', '--quiet', 'HEAD', '--'];

	try {
		_exec2.default.git.apply(_exec2.default, args);
	} catch (e) {
		throw new Error('There are uncommited changes.');
	}
}

function push(ref) {
	var args = ['push', 'origin', ref];
	_exec2.default.git.apply(_exec2.default, args);
}

function stash() {
	var args = ['stash', '--include-untracked', '--quiet'];
	_exec2.default.git.apply(_exec2.default, args);
}

function unstash() {
	var args = ['stash', 'pop', '--quiet'];
	_exec2.default.git.apply(_exec2.default, args);
}

function add() {
	var args = ['add', '--all', '--ignore-errors'];
	_exec2.default.git.apply(_exec2.default, args);
}

function commit(msg) {
	var args = ['commit', '-m', '' + msg, '--quiet'];
	_exec2.default.git.apply(_exec2.default, args);
}

exports.default = {
	tagExists: tagExists,
	tag: tag,
	getCurrentBranch: getCurrentBranch,
	checkout: checkout,
	checkUncommittedChanges: checkUncommittedChanges,
	push: push,
	stash: stash,
	unstash: unstash,
	commit: commit,
	add: add
};
module.exports = exports['default'];